@@ -65,7 +65,7 @@ def array_from_dict_values(dct, sorted_keys=None, flat_output=False, dtype=np.fl
     """
     if sorted_keys is None:
         sorted_keys = sorted(dct)
-    iterable_values = isinstance(dct[sorted_keys[0]], collections.Iterable)
+    iterable_values = isinstance(dct[sorted_keys[0]], collections.abc.Iterable)
     if iterable_values:
         it = itertools.chain.from_iterable(dct[key] for key in sorted_keys)
     else:
@@ -544,9 +544,9 @@ def distribute_regions_among_components(component_labels, n_regions):
     component_labels : list
         Each element specifies to which connected component an area belongs.
         An example would be [0, 0, 1, 0, 0, 1] for the following two islands:
-        
+
         ::
-        
+
           island one        island two
           .-------.         .---.
           | 0 | 1 |         | 2 |
@@ -903,10 +903,10 @@ def check_solver(solver):
 
 def get_solver_instance(solver_string):
     solver = {
-        "cbc": pulp.solvers.PULP_CBC_CMD,
-        "cplex": pulp.solvers.CPLEX,
-        "glpk": pulp.solvers.GLPK,
-        "gurobi": pulp.solvers.GUROBI,
+        "cbc": pulp.PULP_CBC_CMD,
+        "cplex": pulp.CPLEX,
+        "glpk": pulp.GLPK,
+        "gurobi": pulp.GUROBI,
     }[solver_string.lower()]
     solver_instance = solver()
     return solver_instance
